@@ -1,7 +1,7 @@
 library(GPFDA)
 require(MASS)
 
-set.seed(60)
+
 hp <- list('pow.ex.w'=rep(log(10),4),'linear.a'=rep(log(10),4),'pow.ex.v'=log(5),'vv'=log(1))
 kernal <- c('linear','pow.ex')
 
@@ -15,8 +15,7 @@ X[,1]=seq(-5,10,len=800)
 X[,2]=seq(0,1,len=800)
 X[,3]=seq(-15,-10,len=800)
 X[,4]=seq(1,2,len=800)
-# Y=mvrnorm(n=200,mu=as.matrix(X[,1]-X[,1]),Sigma=(cov.linear(hp,X)+cov.pow.ex(hp,X)))[1,]+0.2*sign(X[,1])*abs(X[,1])^(1/3)-4*sin(X[,2])
-Y=(mvrnorm(n=800,mu=as.matrix(X[,1]-X[,1]),Sigma=(cov.linear(hp,X)+cov.pow.ex(hp,X)))[1,])+
+Y=(mvrnorm(n=800,mu=as.matrix(X[,1]-X[,1]),Sigma=(cov.linear(hp,X)+cov.pow.ex(hp,X)))[,1])*0.002+
   (0.2*sign(X[,1])*abs(X[,1])^(1/3)-4*sin(X[,2])+exp(X[,3])+log(X[,4]))*3
 X=X[idx,];Y=as.matrix(Y[idx])
 x=matrix(0,ncol=4,nrow=mm)
@@ -25,15 +24,13 @@ x[,2]=seq(0,1,len=mm)
 x[,3]=seq(-15,-10,len=mm)
 x[,4]=seq(1,2,len=mm)
 
-a=gpr(X,Y,kernal,hp)
+a=gpr(X,Y,kernal,trace=2)
 b=gppredict(a,x)
 
-upper=b$mu+1.96*b$sigma
-lower=b$mu-1.96*b$sigma
+upper=b$mu+1.96*sqrt(b$sigma)
+lower=b$mu-1.96*sqrt(b$sigma)
 plot(-100,-100,col=0,xlim=range(x[,1]),ylim=c(min(upper,lower,Y)-0.1*abs(min(upper,lower,Y)),max(upper,lower,Y)+0.1*abs(max(upper,lower,Y))),main="Prediction", xlab="input ( x )",ylab="response")
-polygon(c(x[,1], rev(x[,1])), c(upper, rev(lower)),col = "grey90", border = NA)
-points(X[,1],Y,pch=4,col=2)
-#points(x[,1],a$mu)
-lines(X[,1],Y)
-lines(x[,1],b$mu,col=3,lwd=2)
+polygon(c(x[,1], rev(x[,1])), c(upper, rev(lower)),col = "grey60", border = NA)
+points(X[,1],Y,pch=4,col=2,cex=0.8)
+lines(x[,1],b$mu,col=4,lwd=1.5)
 
